@@ -208,6 +208,19 @@ MYLOG(0, "entering src=%d\n", src);
 	SetDlgItemInt(hdlg, DRV_VARCHAR_SIZE, comval->max_varchar_size, FALSE);
 	SetDlgItemInt(hdlg, DRV_LONGVARCHAR_SIZE, comval->max_longvarchar_size, TRUE);
 	SetDlgItemText(hdlg, DRV_EXTRASYSTABLEPREFIXES, comval->extra_systable_prefixes);
+	switch (src)
+	{
+		case 1:
+			ShowWindow(GetDlgItem(hdlg, DS_BATCH_SIZE), SW_SHOW);
+			ShowWindow(GetDlgItem(hdlg, DS_IGNORETIMEOUT), SW_SHOW);
+			SetDlgItemInt(hdlg, DS_BATCH_SIZE, ci->batch_size, FALSE);
+			CheckDlgButton(hdlg, DS_IGNORETIMEOUT, ci->ignore_timeout);
+			break;
+		default:
+			ShowWindow(GetDlgItem(hdlg, DS_BATCH_SIZE), SW_HIDE);
+			ShowWindow(GetDlgItem(hdlg, DS_IGNORETIMEOUT), SW_HIDE);
+			break;
+	}
 
 	/* Driver Connection Settings */
 	EnableWindow(GetDlgItem(hdlg, DRV_CONNSETTINGS), FALSE);
@@ -257,6 +270,8 @@ MYLOG(3, "entering\n");
 																								 * SQL_NO_TOTAL */
 
 	GetDlgItemText(hdlg, DRV_EXTRASYSTABLEPREFIXES, comval->extra_systable_prefixes, sizeof(comval->extra_systable_prefixes));
+	ci->batch_size = GetDlgItemInt(hdlg, DS_BATCH_SIZE, NULL, FALSE);
+	ci->ignore_timeout = IsDlgButtonChecked(hdlg, DS_IGNORETIMEOUT);
 
 	/* fall through */
 	return 0;
@@ -500,6 +515,13 @@ ds_options_update(HWND hdlg, ConnInfo *ci)
 
 	MYLOG(0, "entering got ci=%p\n", ci);
 
+	/* ExtraOptions */
+	GetDlgItemText(hdlg, DS_EXTRA_OPTIONS, buf, sizeof(buf));
+	if (!setExtraOptions(ci, buf, NULL))
+	{
+		MessageBox(hdlg, "ExtraOptions must be hex, decimal or octal", "Format error", MB_ICONEXCLAMATION | MB_OK);
+		return 1;
+	}
 	/* Readonly */
 	ITOA_FIXED(ci->onlyread, IsDlgButtonChecked(hdlg, DS_READONLY));
 
@@ -540,12 +562,11 @@ ds_options_update(HWND hdlg, ConnInfo *ci)
 	else
 		ci->numeric_as = DEFAULT_NUMERIC_AS;
 
-	GetDlgItemText(hdlg, DS_EXTRA_OPTIONS, buf, sizeof(buf));
-	setExtraOptions(ci, buf, NULL);
 	ITOA_FIXED(ci->show_system_tables, IsDlgButtonChecked(hdlg, DS_SHOWSYSTEMTABLES));
 
 	ITOA_FIXED(ci->row_versioning, IsDlgButtonChecked(hdlg, DS_ROWVERSIONING));
 	ci->lf_conversion = IsDlgButtonChecked(hdlg, DS_LFCONVERSION);
+	ci->optional_errors = IsDlgButtonChecked(hdlg, DS_OPTIONALERRORS);
 	ci->true_is_minus1 = IsDlgButtonChecked(hdlg, DS_TRUEISMINUS1);
 	ci->allow_keyset = IsDlgButtonChecked(hdlg, DS_UPDATABLECURSORS);
 	ci->use_server_side_prepare = IsDlgButtonChecked(hdlg, DS_SERVERSIDEPREPARE);
@@ -566,6 +587,7 @@ ds_options_update(HWND hdlg, ConnInfo *ci)
 
 	/* TCP KEEPALIVE */
 	ci->disable_keepalive = IsDlgButtonChecked(hdlg, DS_DISABLE_KEEPALIVE);
+	ci->extra_opts = getExtraOptions(ci);
 	if (ci->disable_keepalive)
 	{
 		ci->keepalive_idle = -1;
@@ -694,6 +716,7 @@ ds_options2Proc(HWND hdlg,
 			CheckDlgButton(hdlg, DS_ROWVERSIONING, atoi(ci->row_versioning));
 			CheckDlgButton(hdlg, DS_SHOWSYSTEMTABLES, atoi(ci->show_system_tables));
 			CheckDlgButton(hdlg, DS_LFCONVERSION, ci->lf_conversion);
+			CheckDlgButton(hdlg, DS_OPTIONALERRORS, ci->optional_errors);
 			CheckDlgButton(hdlg, DS_TRUEISMINUS1, ci->true_is_minus1);
 			CheckDlgButton(hdlg, DS_UPDATABLECURSORS, ci->allow_keyset);
 			CheckDlgButton(hdlg, DS_SERVERSIDEPREPARE, ci->use_server_side_prepare);
